@@ -52,10 +52,12 @@
 #include "event.h"
 #include "net.h"
 #include "alert.h"
+#include "SMTP.h"
 
 // libmonit
 #include "system/Time.h"
 #include "util/Str.h"
+#include "exceptions/IOException.h"
 
 
 /**
@@ -65,19 +67,164 @@
  */
 
 
-/* -------------------------------------------------------------- Prototypes */
+/* ----------------------------------------------------------------- Private */
 
 
-static void copy_mail(Mail_T, Mail_T);
-static void escape(Mail_T);
-static void substitute(Mail_T, Event_T);
+static void _substitute(Mail_T m, Event_T e) {
+        ASSERT(m);
+        ASSERT(e);
+
+        Util_replaceString(&m->from->address, "$HOST", Run.system->name);
+        Util_replaceString(&m->subject, "$HOST", Run.system->name);
+        Util_replaceString(&m->message, "$HOST", Run.system->name);
+
+        char timestamp[26];
+        Time_string(e->collected.tv_sec, timestamp);
+        Util_replaceString(&m->subject, "$DATE", timestamp);
+        Util_replaceString(&m->message, "$DATE", timestamp);
+
+        Util_replaceString(&m->subject, "$SERVICE", e->source->name);
+        Util_replaceString(&m->message, "$SERVICE", e->source->name);
+
+        const char *description = Event_get_description(e);
+        Util_replaceString(&m->subject, "$EVENT", description);
+        Util_replaceString(&m->message, "$EVENT", description);
+
+        const char *message = NVLSTR(e->message);
+        Util_replaceString(&m->subject, "$DESCRIPTION", message);
+        Util_replaceString(&m->message, "$DESCRIPTION", message);
+
+        const char *action = Event_get_action_description(e);
+        Util_replaceString(&m->subject, "$ACTION", action);
+        Util_replaceString(&m->message, "$ACTION", action);
+}
+
+
+static void _escape(Mail_T m) {
+        // replace bare linefeed
+        Util_replaceString(&m->message, "\r\n", "\n");
+        Util_replaceString(&m->message, "\n", "\r\n");
+        // escape ^.
+        Util_replaceString(&m->message, "\n.", "\n..");
+        // drop any CR|LF from the subject
+        Str_chomp(m->subject);
+}
+
+
+static void _copyMail(Mail_T n, Mail_T o) {
+        ASSERT(n);
+        ASSERT(o);
+
+        n->to = Str_dup(o->to);
+        if (o->from) {
+                n->from = Address_copy(o->from);
+        } else if (Run.MailFormat.from) {
+                n->from = Address_copy(Run.MailFormat.from);
+        } else {
+                n->from = Address_new();
+                n->from->address = Str_dup(ALERT_FROM);
+        }
+        n->replyto = o->replyto ? Address_copy(o->replyto) : Run.MailFormat.replyto ? Address_copy(Run.MailFormat.replyto) : NULL;
+        n->subject = o->subject ? Str_dup(o->subject) : Run.MailFormat.subject ? Str_dup(Run.MailFormat.subject) : Str_dup(ALERT_SUBJECT);
+        n->message = o->message ? Str_dup(o->message) : Run.MailFormat.message ? Str_dup(Run.MailFormat.message) : Str_dup(ALERT_MESSAGE);
+}
+
+
+static MailServer_T _connectMTA() {
+        if (! Run.mailservers)
+                THROW(IOException, "No mail servers are defined -- see manual for 'set mailserver' statement");
+        MailServer_T mta = NULL;
+        for (mta = Run.mailservers; mta; mta = mta->next) {
+                DEBUG("Trying to send mail via %s:%i\n", mta->host, mta->port);
+                if (mta->ssl.flags == SSL_Enabled)
+                        mta->socket = Socket_create(mta->host, mta->port, Socket_Tcp, Socket_Ip, mta->ssl, Run.mailserver_timeout);
+                else
+                        mta->socket = Socket_new(mta->host, mta->port, Socket_Tcp, Socket_Ip, false, Run.mailserver_timeout);
+                if (mta->socket)
+                        break;
+                else
+                        LogError("Cannot open a connection to the mailserver %s:%i -- %s\n", mta->host, mta->port, STRERROR);
+        }
+        if (! mta || ! mta->socket)
+                THROW(IOException, "Delivery failed -- no mail server is available");
+        return mta;
+}
+
+
+static boolean_t _sendMail(Mail_T mail) {
+        ASSERT(mail);
+        boolean_t failed = false;
+        volatile SMTP_T smtp = NULL;
+        volatile MailServer_T mta = NULL;
+        TRY
+        {
+                mta = _connectMTA();
+                smtp = SMTP_new(mta->socket);
+                SMTP_greeting(smtp);
+                SMTP_helo(smtp, Run.mail_hostname ? Run.mail_hostname : Run.system->name);
+                if (mta->ssl.flags == SSL_StartTLS)
+                        SMTP_starttls(smtp, mta->ssl);
+                if (mta->username && mta->password)
+                        SMTP_auth(smtp, mta->username, mta->password);
+                char now[STRLEN];
+                Time_gmtstring(Time_now(), now);
+                for (Mail_T m = mail; m; m = m->next) {
+                        SMTP_from(smtp, m->from->address);
+                        SMTP_to(smtp, m->to);
+                        SMTP_dataBegin(smtp);
+                        if (
+                                (m->replyto && ((m->replyto->name ? Socket_print(mta->socket, "Reply-To: \"%s\" <%s>\r\n", m->replyto->name, m->replyto->address) : Socket_print(mta->socket, "Reply-To: %s\r\n", m->replyto->address)) <= 0))
+                                ||
+                                ((m->from->name ? Socket_print(mta->socket, "From: \"%s\" <%s>\r\n", m->from->name, m->from->address) : Socket_print(mta->socket, "From: %s\r\n", m->from->address)) <= 0)
+                                ||
+                                Socket_print(mta->socket,
+                                        "To: %s\r\n"
+                                        "Subject: %s\r\n"
+                                        "Date: %s\r\n"
+                                        "X-Mailer: Monit %s\r\n"
+                                        "MIME-Version: 1.0\r\n"
+                                        "Content-Type: text/plain; charset=\"iso-8859-1\"\r\n"
+                                        "Content-Transfer-Encoding: 8bit\r\n"
+                                        "Message-Id: <%lld.%lu@%s>\r\n"
+                                        "\r\n"
+                                        "%s",
+                                        m->to,
+                                        m->subject,
+                                        now,
+                                        VERSION,
+                                        (long long)Time_now(), random(), Run.mail_hostname ? Run.mail_hostname : Run.system->name,
+                                        m->message) <= 0
+                           )
+                        {
+                                THROW(IOException, "Error sending data to mail server %s -- %s", mta->host, STRERROR);
+                        }
+                        SMTP_dataCommit(smtp);
+                }
+                SMTP_quit(smtp);
+        }
+        ELSE
+        {
+                failed = true;
+                LogError("Mail: %s\n", Exception_frame.message);
+        }
+        FINALLY
+        {
+                if (smtp)
+                        SMTP_free((SMTP_T *)&smtp);
+                if (mta && mta->socket)
+                        Socket_free(&(mta->socket));
+
+        }
+        END_TRY;
+        return failed;
+}
 
 
 /* ------------------------------------------------------------------ Public */
 
 
 /**
- * Notify registred users about the event
+ * Notify registered users about the event
  * @param E An Event object
  * @return If failed, return Handler_Alert flag or Handler_Succeeded if succeeded
  */
@@ -106,9 +253,9 @@ Handler_Type handle_alert(Event_T E) {
                         {
                                 Mail_T tmp = NULL;
                                 NEW(tmp);
-                                copy_mail(tmp, m);
-                                substitute(tmp, E);
-                                escape(tmp);
+                                _copyMail(tmp, m);
+                                _substitute(tmp, E);
+                                _escape(tmp);
                                 tmp->next = list;
                                 list = tmp;
                                 DEBUG("Sending %s notification to %s\n", Event_get_description(E), m->to);
@@ -143,16 +290,16 @@ Handler_Type handle_alert(Event_T E) {
                         {
                                 Mail_T tmp = NULL;
                                 NEW(tmp);
-                                copy_mail(tmp, m);
-                                substitute(tmp, E);
-                                escape(tmp);
+                                _copyMail(tmp, m);
+                                _substitute(tmp, E);
+                                _escape(tmp);
                                 tmp->next = list;
                                 list = tmp;
                                 DEBUG("Sending %s notification to %s\n", Event_get_description(E), m->to);
                         }
                 }
                 if (list) {
-                        if (sendmail(list))
+                        if (_sendMail(list))
                                 rv = Handler_Alert;
                         gc_mail_list(&list);
                 }
@@ -160,55 +307,3 @@ Handler_Type handle_alert(Event_T E) {
         return rv;
 }
 
-
-static void substitute(Mail_T m, Event_T e) {
-        ASSERT(m);
-        ASSERT(e);
-
-        Util_replaceString(&m->from,    "$HOST", Run.system->name);
-        Util_replaceString(&m->subject, "$HOST", Run.system->name);
-        Util_replaceString(&m->message, "$HOST", Run.system->name);
-
-        char timestamp[26];
-        Time_string(e->collected.tv_sec, timestamp);
-        Util_replaceString(&m->subject, "$DATE", timestamp);
-        Util_replaceString(&m->message, "$DATE", timestamp);
-
-        Util_replaceString(&m->subject, "$SERVICE", e->source->name);
-        Util_replaceString(&m->message, "$SERVICE", e->source->name);
-
-        const char *description = Event_get_description(e);
-        Util_replaceString(&m->subject, "$EVENT", description);
-        Util_replaceString(&m->message, "$EVENT", description);
-
-        const char *message = NVLSTR(e->message);
-        Util_replaceString(&m->subject, "$DESCRIPTION", message);
-        Util_replaceString(&m->message, "$DESCRIPTION", message);
-
-        const char *action = Event_get_action_description(e);
-        Util_replaceString(&m->subject, "$ACTION", action);
-        Util_replaceString(&m->message, "$ACTION", action);
-}
-
-
-static void copy_mail(Mail_T n, Mail_T o) {
-        ASSERT(n && o);
-
-        n->to = Str_dup(o->to);
-        n->from = o->from ? Str_dup(o->from) : Run.MailFormat.from ? Str_dup(Run.MailFormat.from) : Str_dup(ALERT_FROM);
-        n->replyto = o->replyto ? Str_dup(o->replyto) : Run.MailFormat.replyto ? Str_dup(Run.MailFormat.replyto) : NULL;
-        n->subject = o->subject ? Str_dup(o->subject) : Run.MailFormat.subject ? Str_dup(Run.MailFormat.subject) : Str_dup(ALERT_SUBJECT);
-        n->message = o->message ? Str_dup(o->message) : Run.MailFormat.message ? Str_dup(Run.MailFormat.message) : Str_dup(ALERT_MESSAGE);
-}
-
-
-static void escape(Mail_T m) {
-        // replace bare linefeed
-        Util_replaceString(&m->message, "\r\n", "\n");
-        Util_replaceString(&m->message, "\n", "\r\n");
-        // escape ^.
-        Util_replaceString(&m->message, "\n.", "\n..");
-        // drop any CR|LF from the subject
-        Str_chomp(m->subject);
-}
-
